# Digolds.cn visitor

digolds-cn is a test projet for learning package and distribute local lib to PyPI.

## Installation

You can install the digolds.cn visitor by typing following command:

    python -m pip install digolds-cn

## How to use

After install succesfully, you can show digolds's home page directly in terminal with following command:

```bash
digolds
```